@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.72 2006/06/08 14:12:47 evertonm Exp $ */
+/* $Id: common.c,v 1.76 2006/06/29 20:55:25 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,7 +47,7 @@ static int line = 0;
 
 const char *nepim_version()
 {
-  return "0.32";
+  return "0.33";
 }
 
 static void header(FILE *out, int ident, int udp)
@@ -58,7 +58,7 @@ static void header(FILE *out, int ident, int udp)
     fprintf(out, " %10s %10s %8s %8s", 
 	    "kbps_in", "kbps_out", "rcv/s", "snd/s");
     if (udp)
-      fprintf(out, "  %5s  %5s", "loss", "ooo");
+      fprintf(out, " %5s %5s", "loss", "ooo");
     fprintf(out, "\n");
   }
 }
@@ -139,11 +139,21 @@ void nepim_slot_stat(FILE *out, struct timeval now,
     
     loss_ratio /= pkt_expected;
     ooo_ratio  /= pkt_expected;
-    
+
+#if 0
     fprintf(out,
-            " %5.4f %5.4f",
+            " %-5.4f %-5.4f",
             loss_ratio,
 	    ooo_ratio);
+#endif
+
+    pr = snprintf(buf, sizeof buf, "%6.4f", loss_ratio);
+    assert(pr == 6); /* 0.0000 */
+    fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
+
+    pr = snprintf(buf, sizeof buf, "%6.4f", ooo_ratio);
+    assert(pr == 6); /* 0.0000 */
+    fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
   }
 
   fprintf(out, "\n");
@@ -280,6 +290,10 @@ int nepim_pps2packets(int pps_pkt_rate, susec_t usec_delay)
   assert(pkts > -NEPIM_2MEGA);
   assert(pkts < NEPIM_2MEGA);
 
+#if 0
+  fprintf(stderr, "XXX pkt_rate=%d delay=%ld packets=%lld\n", pps_pkt_rate, usec_delay, pkts);
+#endif
+
   return pkts;
 }
 
@@ -415,6 +429,7 @@ struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
     struct addrinfo hints;
     struct addrinfo *ai_res;
     struct addrinfo *ai;
+    int result;
 
     if (addr_list_get(list, i, hostname, sizeof(hostname))) {
       fprintf(stderr, 
@@ -435,8 +450,7 @@ struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
     hints.ai_flags    = AI_CANONNAME;
     hints.ai_family   = PF_UNSPEC;
 
-    int result = getaddrinfo(hostname, portname,
-			     &hints, &ai_res);
+    result = getaddrinfo(hostname, portname, &hints, &ai_res);
     if (result) {
       fprintf(stderr, "%s %s: getaddrinfo(%s,%s): %s\n",
 	      __FILE__, __PRETTY_FUNCTION__,
