@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.61 2006/06/12 14:58:32 evertonm Exp $
+  $Id: main.c,v 1.62 2006/06/14 17:36:34 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -655,7 +655,7 @@ int main(int argc, const char *argv[])
       if (pkts < 1) {
         int min_pps = nepim_min_pps(nepim_global.write_delay);
         fprintf(stderr,
-                "%s: pkt-rate=%d pps (pkts=%d) lower than minimum=%d pps (for send-delay=%ld ms)\n",
+                "%s: pkt-rate=%d pps (pkts=%d) lower than min=%d pps (for send-delay=%ld ms)\n",
                 nepim_global.prog_name, 
                 nepim_global.pkt_rate, pkts, min_pps, nepim_global.write_delay);
         exit(1);
@@ -665,6 +665,7 @@ int main(int argc, const char *argv[])
     }
 
     if (!strcmp(arg, "-e")) {
+      int pkts;
       ++i;
       if (i >= argc) {
         fprintf(stderr, "%s: missing send-rate\n",
@@ -687,7 +688,25 @@ int main(int argc, const char *argv[])
 
       nepim_global.write_delay = NEPIM_MEGA / nepim_global.pkt_rate;
 
+      pkts = nepim_pps2packets(nepim_global.pkt_rate,
+                               nepim_global.write_delay);
+      if (pkts < 1) {
+	++nepim_global.write_delay; /* fix rounding error */
+#if 0
+        fprintf(stderr,
+                "ugh: pkt-rate=%d delay=%ld pkts=%d\n",
+                nepim_global.pkt_rate, nepim_global.write_delay, pkts);
+	assert(0);
+        exit(1);
+#endif
+      }
+
+      pkts = nepim_pps2packets(nepim_global.pkt_rate,
+                               nepim_global.write_delay);
+      assert(pkts >= 1);
+
       assert(nepim_global.pkt_rate >= nepim_min_pps(nepim_global.write_delay));
+
       continue;
     }
 
