@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.73 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.75 2006/06/07 15:27:43 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -210,7 +210,7 @@ static void udp_slot_start(nepim_slot_t *slot)
                                 session->tv_duration,
                                 on_udp_duration, slot);
 
-  nepim_sock_show_opt(stderr, slot->udp_sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, slot->udp_sd);
 
   schedule_stat_interval(slot);
 
@@ -1041,7 +1041,7 @@ static void udp_slot_cancel_io(nepim_slot_t *slot)
 
 static void udp_slot_kill(nepim_slot_t *slot)
 {
-  nepim_sock_show_opt(stderr, slot->udp_sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, slot->udp_sd);
 
   udp_slot_cancel_stat_timers(slot);
   udp_slot_cancel_io(slot);
@@ -1253,7 +1253,8 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
     if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
       continue;
 
-    sd = nepim_connect_client_socket(bindaddr, bindaddr_len,
+    sd = nepim_connect_client_socket(nepim_global.verbose_stderr,
+				     bindaddr, bindaddr_len,
 				     ai->ai_addr, ai->ai_addrlen,
                                      ai->ai_family, ai->ai_socktype, 
                                      ai->ai_protocol,
