@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.98 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.100 2006/06/07 15:27:43 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -241,7 +241,7 @@ static void udp_slot_kill(nepim_slot_t *slot)
 				      slot->session.tv_keepalive_recv_timer,
 				      on_udp_keepalive_require, slot);
 
-  nepim_sock_show_opt(stderr, slot->udp_sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, slot->udp_sd);
 
   nepim_slot_set_del(&slots, slot_index);
 }
@@ -686,7 +686,7 @@ static void udp_slot_start(int local_slot)
 				session->tv_duration,
 				on_udp_duration, slot);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 
   schedule_stat_interval(local_slot);
 
@@ -995,7 +995,8 @@ static void *on_udp_segment(oop_source *src, int sd,
       multiple UDP clients (slots) on the same socket will
       probably clash distinct requests for socket keepalive
      */
-    nepim_socket_keepalive(sd, opt.socket_keepalive);
+    nepim_socket_keepalive(nepim_global.verbose_stderr,
+			   sd, opt.socket_keepalive);
 
     nepim_slot_set_add(&slots, sd, 
 		       local_slot, hdr.src_slot,
@@ -1102,7 +1103,8 @@ int nepim_udp_listener(const char *hostname, const char *portname,
     nepim_sock_dump_addr(addr_str, sizeof addr_str,
 			 ai->ai_addr, ai->ai_addrlen);
 
-    sd = nepim_create_socket(ai->ai_addr, ai->ai_addrlen,
+    sd = nepim_create_socket(nepim_global.verbose_stderr,
+			     ai->ai_addr, ai->ai_addrlen,
 			     ai->ai_family, ai->ai_socktype, 
 			     ai->ai_protocol,
 			     nepim_global.pmtu_mode,
@@ -1132,7 +1134,7 @@ int nepim_udp_listener(const char *hostname, const char *portname,
 	    "%d: UDP socket listening on %s,%d\n",
 	    sd, addr_str, nepim_sock_get_port(ai->ai_addr));
 
-    nepim_sock_show_opt(stderr, sd);
+    nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
   }
 
   freeaddrinfo(ai_res);
@@ -1159,7 +1161,8 @@ int nepim_unix_dgram_listener(const char *path)
   un_sock_addr.sun_family = AF_UNIX;
   strcpy(un_sock_addr.sun_path, path);
   
-  sd = nepim_create_socket((struct sockaddr *) &un_sock_addr, 
+  sd = nepim_create_socket(nepim_global.verbose_stderr,
+			   (struct sockaddr *) &un_sock_addr, 
 			   sizeof(un_sock_addr),
 			   AF_UNIX,
 			   SOCK_DGRAM, 
@@ -1188,7 +1191,7 @@ int nepim_unix_dgram_listener(const char *path)
 	  "%d: UNIX datagram socket listening on path=%s\n",
 	  sd, path);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 
   return 1;
 }
